#!/usr/bin/fades

"""Mirror the followers in Mastodon."""

import sys
import itertools

import atproto  # fades
import infoauth  # fades


USER_INFO = "{0.display_name} ({0.handle}) - {0.avatar}"


def main(filepath):
    """Main entry point."""
    auth_info = infoauth.load(filepath)
    client = atproto.Client()
    client.login(auth_info["username"], auth_info["password"])
    did = client.me.did

    response = client.get_followers(did)
    current_followers = response.followers

    response = client.get_follows(did)
    current_followingto = response.follows

    print("Current followers", len(current_followers))
    print("Current following to", len(current_followingto))

    all_accounts = {
        acc.did: acc for acc in itertools.chain(current_followingto, current_followers)
    }
    follower_ids = set(acc.did for acc in current_followers)
    followingto_ids = set(acc.did for acc in current_followingto)
    those_to_follow = follower_ids - followingto_ids
    those_to_unfollow = followingto_ids - follower_ids

    print("Following to", len(those_to_follow))
    for acc_id in those_to_follow:
        acc = all_accounts[acc_id]
        print("  ", USER_INFO.format(acc))
        client.follow(acc.did)

    print("(PAUSED!!!) Unfollowing to", len(those_to_unfollow))
    for acc_id in those_to_unfollow:
        acc = all_accounts[acc_id]
        print("  ", USER_INFO.format(acc))
        # mastodon.account_unfollow(acc_id)


if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("USAGE: bluesky-autofollower.py <filepath to infoauth secrets>")
        exit()
    main(sys.argv[1])
